@@ -5,7 +5,8 @@ from solitude import hookimpl
 
 def filter_csubmit_command_str(cmd: str) -> str:
     result = re.search(
-        r"c-submit\s+(?:--[\S-]+(?:=\S+)?\s+)*[\S]+\s+\S+\s\d+\s(\S+)(.*)", cmd.strip()
+        r"c-submit\s+(?:--[\S-]+(?:=\S+)?\s+)*[\S]+\s+\S+\s\d+\s(\S+)(.*)",
+        cmd.strip(),
     )
     return (result.groups()[0] + result.groups()[1]).strip()
 
