@@ -31,9 +31,9 @@ def get_command_status_str(cmd: str, state: Dict) -> str:
 @hookimpl
 def get_errors_from_log(log: str) -> List[str]:
     errors = []
-    if log.find('Killed') != -1:
+    if log.find("Killed") != -1:
         errors.append("NoResource")
-    if log.find('CUDA_ERROR') != -1:
+    if log.find("CUDA_ERROR") != -1:
         errors.append("CUDA")
-    errors = errors + [e[1:-1] for e in re.findall(r'\s.*Error:', log)]
+    errors = errors + [e[1:-1] for e in re.findall(r"\s.*Error:", log)]
     return errors
