@@ -1,12 +1,14 @@
 from typing import Dict, List
 from solitude import hookimpl
-from solitude.plugins.csubmit import get_errors_from_log as _get_errors_from_log
+from solitude.plugins.csubmit import (
+    get_errors_from_log as _get_errors_from_log,
+)
 from solitude.plugins.csubmit import filter_csubmit_command_str
 
 
 @hookimpl
 def matches_command(cmd: str) -> bool:
-    return ('c-submit ' in cmd) and ('--interactive' in cmd)
+    return ("c-submit " in cmd) and ("--interactive" in cmd)
 
 
 @hookimpl
